VideoFeatureConfig class

Settings for optional video_compress after ImagePicker.pickVideo.

Constructors

VideoFeatureConfig({bool enabled = true, bool compressAfterPick = true, VideoQuality quality = VideoQuality.Res1280x720Quality, bool deleteOriginAfterCompress = false, Duration? maxDuration})
const

Properties

compressAfterPick bool
When false, returns the original picked file without calling VideoCompress.compressVideo.
final
deleteOriginAfterCompress bool
Passed to VideoCompress.compressVideo when compressAfterPick is true.
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
maxDuration Duration?
Forwarded to ImagePicker.pickVideo.
final
quality VideoQuality
Preset passed to VideoCompress.compressVideo.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited