compressAfterPick property
When false, returns the original picked file without calling VideoCompress.compressVideo.
Implementation
final bool compressAfterPick;
When false, returns the original picked file without calling VideoCompress.compressVideo.
final bool compressAfterPick;