image_selector library

Classes

CameraUiSettings
CompressParams
CropAspectRatioPresetData
A set of preset values can be used to setup the menu of crop aspect ratio options in the cropper view.
CropFeatureConfig
Settings for optional image_cropper integration (avatar / Instagram-style crop).
ImageSelect
ImageSelectFeatureConfig
Optional add-ons for ImageSelect. Pass only what you need; null means that feature is off (no crop step, no video helpers, default gallery multi-pick).
LostDataResponse
The response object of ImagePicker.getLostData.
VideoFeatureConfig
Settings for optional video_compress after ImagePicker.pickVideo.
WebFilePickerFeatureConfig
Use file_picker for multi-image selection (strong on web and desktop).
XFile
A CrossFile is a cross-platform, simplified File abstraction.

Enums

CameraSide
CropAspectRatioPreset
CropStyle
Crop style options. There're two supported styles, rectangle and circle. These style will changes the shape of crop bounds, rectangle or circle bounds.
ImageCompressFormat
Supported image compression formats
ImageFrom
RetrieveType
The type of the retrieved data in a LostDataResponse.
VideoQuality