CropFeatureConfig class
Settings for optional image_cropper integration (avatar / Instagram-style crop).
Constructors
-
CropFeatureConfig({bool enabled = true, int compressQuality = 90, List<
CropAspectRatioPresetData> aspectRatioPresets = const <CropAspectRatioPresetData>[CropAspectRatioPreset.square, CropAspectRatioPreset.original], bool lockAspectRatio = false, CropStyle cropStyle = CropStyle.rectangle, String androidToolbarTitle = 'Crop', String iosTitle = 'Crop', int? maxWidth, int? maxHeight}) -
const
Properties
- androidToolbarTitle → String
-
final
-
aspectRatioPresets
→ List<
CropAspectRatioPresetData> -
final
- compressQuality → int
-
0–100 passed to
ImageCropper.cropImage.final - cropStyle → CropStyle
-
final
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iosTitle → String
-
final
- lockAspectRatio → bool
-
final
- maxHeight → int?
-
final
- maxWidth → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited