WebFilePickerFeatureConfig class
Use file_picker for multi-image selection (strong on web and desktop).
When useFilePickerForMultiPick is true, ImageSelect.pickMultiImagesAsXFiles can
use file_picker instead of ImagePicker.pickMultiImage (see method docs).
Constructors
- WebFilePickerFeatureConfig({bool enabled = true, bool useFilePickerForMultiPick = true, bool withData = true})
-
const
Properties
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- useFilePickerForMultiPick → bool
-
If true, multi selection may go through
FilePicker.platform.pickFileswhen supported.final - withData → bool
-
Web: load bytes in memory (needed when path is unavailable).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited